# DO NOT EDIT THIS FILE! This file gets overwritten for each update.
# Use files in /etc/opencpu to customize server config

# Try to find system default 'LANG' variable
if(!grepl("UTF-?8", Sys.getenv("LANG"))){
  if(file.exists("/etc/default/locale")){
    try(readRenviron("/etc/default/locale"))
  }
}

# Possibly override 'LANG' by user
if(file.exists("/etc/opencpu/Renviron"))
  readRenviron("/etc/opencpu/Renviron")

# Default locale in apache is "C", use 'LANG' if possible
if(!grepl("UTF-?8", Sys.getlocale("LC_CTYPE"))){
  if(grepl("UTF-?8", Sys.getenv("LANG"))){
    Sys.setlocale(category = "LC_ALL", Sys.getenv("LANG"))
  }
}

# If this didn't try "en_US.UTF-8" instead
if(!grepl("UTF-?8", Sys.getlocale("LC_CTYPE"))){
  Sys.setlocale(category = "LC_ALL", "en_US.UTF-8")
  Sys.setenv(LANG = Sys.getlocale("LC_CTYPE"))
}

# Print final locale to log
cat("Using locale:", Sys.getlocale("LC_CTYPE"), "\n")

# Load the opencpu package libraries
.libPaths(c('/usr/lib/opencpu/library', '/usr/local/lib/opencpu/site-library'))

#Load suggested packages while they are in .libPaths()
getNamespace("unix")
getNamespace("sendmailR")

#Try to disable interactivity
#try(.Call(parallel:::C_mc_interactive, FALSE))
sys:::set_interactive(FALSE)

#We use this later
options(rapache = TRUE)

#Check if AppArmor is available
if(identical(sys::aa_config()$con, "unconfined")){
  options(apparmor = TRUE)
  cat("AppArmor available! Running OpenCPU with security profile and rlimits.\n")
} else {
  cat("AppArmor not available. Running OpenCPU without security profile but with rlimits.\n")
}

#Warm up graphics device
options(bitmapType = "cairo")
pdf("/dev/null", width = 11.69, height = 8.27)
plot(1:10)
dev.off()

# Warm up evaluate
for(i in 1:5){
  invisible(evaluate::evaluate('jsonlite::toJSON(openssl::rand_num(1000))'))
}

# Run user script
if(file.exists("/etc/opencpu/Rprofile"))
  source("/etc/opencpu/Rprofile")
